
//		Copyright © 1999		Matthew S. Chartier (mattc@ic.net)
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//


#include "scsi.h"
#include "ppa_lowlevel.h"


status_t scsi_ppa_Init(void)
	{
	return(ppa_init());
	}

status_t scsi_ppa_TestUnitReady(void)
	{
	CMD_TestUnitReady cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode = SCSICMD_TESTUNITREADY;		
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}
	
status_t scsi_ppa_Inquiry(InquiryData* data)
	{
	CMD_Inquiry cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode	= SCSICMD_INQUIRY;
	cmd.lun		= PPA_ZIP_LUN;
	
	return(ppa_SendCommand(&cmd,sizeof(cmd),data,sizeof(InquiryData)));
	}	
	
status_t scsi_ppa_Read(void* buf,ulong bufsize,ulong logicalBlock,ulong count)
	{
	CMD_Read cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode			= SCSICMD_READ;
	cmd.lb				= logicalBlock >> 16;
	cmd.logicalBlock[0] = logicalBlock >> 8;
	cmd.logicalBlock[1] = logicalBlock;
	cmd.length			= count;
	
	return(ppa_SendCommand(&cmd,sizeof(cmd),buf,bufsize));
	}
	
status_t scsi_ppa_Write(void* buf,ulong bufsize,ulong logicalBlock,ulong count)
	{
	CMD_Write cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode			= SCSICMD_WRITE;
	cmd.lb				= logicalBlock >> 16;
	cmd.logicalBlock[0] = logicalBlock >> 8;
	cmd.logicalBlock[1] = logicalBlock;
	cmd.length			= count;
	
	return(ppa_SendCommand(&cmd,sizeof(cmd),buf,bufsize));
	}
	
status_t scsi_ppa_Lock(void)
	{
	CMD_LockUnlock cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode		= SCSICMD_LOCKUNLOCK;
	cmd.prevent		= true;
	
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}	
		
status_t scsi_ppa_Unlock(void)
	{
	CMD_LockUnlock cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode		= SCSICMD_LOCKUNLOCK;
	cmd.prevent		= false;
	
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}	

status_t scsi_ppa_Start(void)
	{
	CMD_StartStop cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode		= SCSICMD_STARTSTOP;
	cmd.eject		= false;
	cmd.start		= true;
		
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}	

status_t scsi_ppa_Stop(void)
	{
	CMD_StartStop cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode		= SCSICMD_STARTSTOP;
	cmd.eject		= false;
	cmd.start		= false;
		
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}	

status_t scsi_ppa_Eject(void)
	{
	CMD_StartStop cmd;
	memset(&cmd,0,sizeof(cmd));
	
	cmd.opcode		= SCSICMD_STARTSTOP;
	cmd.eject		= true;
	cmd.start		= true;
		
	return(ppa_SendCommand(&cmd,sizeof(cmd),NULL,0));
	}	

			